@@ -161,8 +161,17 @@ class StackParameters(object):
 
         self.stackset_admin_role_arn: Optional[str] = self.stack_definition.get('admin_role_arn')
         self.stackset_exec_role_name: Optional[str] = self.stack_definition.get('exec_role_name')
+        self.stackset_call_as: Optional[str] = self.stack_definition.get('call_as', 'self')
+        if self.stackset_call_as not in ('self', 'delegated_admin'):
+            raise InvalidStackConfiguration(f'call_as for [{self.stack_definition["name"]}]'
+                f' must be "self" or "delegated_admin", not [{self.stackset_call_as}]')
         self.operation_preferences: Dict[str, Union[str, List[str]]] = \
                 self.stack_definition.get('operation_preferences', {})
+        self.rollout_strategy: str = self.stack_definition.get('rollout_strategy', 'accounts')
+        if self.rollout_strategy not in ('accounts', 'organization'):
+            raise InvalidStackConfiguration(f'rollout_strategy for [{self.stack_definition["name"]}]'
+                f' must be "accounts" or "organization", not [{self.rollout_strategy}]')
+        self.rollout_autodeploy: Dict[str, bool] = self.stack_definition.get('rollout_autodeploy', {'enable': False})
         self.rollout = self.format_rollout()
 
     def format_rollout(self):
@@ -176,9 +185,23 @@ class StackParameters(object):
                 for k, v in xr.get('override', dict()).items() if v is not None]
         return rollout
 
+    def format_rollout_autodeploy(self):
+        if self.rollout_strategy != 'organization':
+            return dict()
+        rollout_autodeploy = {
+            'AutoDeployment': {
+                'Enabled': self.rollout_autodeploy['enable']
+            }
+        }
+        if self.rollout_autodeploy['enable']:
+            rollout_autodeploy['AutoDeployment']['RetainStacksOnAccountRemoval'] = \
+                self.rollout_autodeploy.get('retain_on_removal', False)
+        return rollout_autodeploy
+
     def configure_parameters_loader(self):
         class ParametersLoader(yaml.Loader):
             pass
+        ParametersLoader.add_constructor('!Include', self.include_file)
         ParametersLoader.add_constructor('!Builtin', self.set_builtin)
         ParametersLoader.add_constructor('!LambdaZip', self.set_lambda_zip)
         ParametersLoader.add_constructor('!CloudformationTemplateS3Key', self.set_cloudformation_template_s3_key)
@@ -191,6 +214,13 @@ class StackParameters(object):
         ParametersLoader.add_constructor('!ArtifactImage', self.set_artifact_image)
         return ParametersLoader
 
+    def include_file(self, loader, node):
+        param_name = loader.construct_scalar(node)
+        log.debug(f'Loading include file {param_name}...')
+        val = self.read_parameters_yaml(os.path.join(self.parameters_dir, param_name))
+        log.debug(f'Successfully read include file {param_name}')
+        return val
+
     def set_builtin(self, loader, node):
         param_name = loader.construct_scalar(node)
         log.debug(f'Setting parameter {param_name}...')
